@@ -1,4 +1,4 @@
 from .base_component import BaseComponent
 from .exact_literal import ExactLiteral
-from .random_group import RandomGroup, LengthRange
+from .random_group import RandomGroup, LengthRange, LengthSequence
 from .one_of import OneOf
\ No newline at end of file
